#version 150

#moj_import <fog.glsl>

in vec3 Position;
in vec4 Color;
in vec2 UV0;
in ivec2 UV2;

uniform sampler2D Sampler2;

uniform mat4 ModelViewMat;
uniform mat4 ProjMat;
uniform int FogShape;
uniform vec2 ScreenSize;

out float vertexDistance;
out vec4 vertexColor;
out vec2 texCoord0;
out vec2 coord;
out vec2 coord_c;
out float flash;

void main() {
    gl_Position = ProjMat * ModelViewMat * vec4(Position, 1.0);
    vertexDistance = fog_distance(Position, FogShape);
    vertexColor = Color * texelFetch(Sampler2, UV2 / 16, 0);
    texCoord0 = UV0;

    float guiScale = (round(ScreenSize.x * ProjMat[0][0] / 2));
    vec3 iColor = vec3(Color.x*255,Color.y*255,Color.z*255);
    
    // Move bossbars
    if (Position.z == 1000 || Position.z == 1000.03) {
        if (gl_Position.y > 1.0 - 30/ScreenSize.y*guiScale) {
            gl_Position.y += -2.0 + 100/ScreenSize.y*guiScale;
        } else {
            gl_Position = ProjMat * ModelViewMat * (vec4(Position, 1.0) - vec4(0,34,0,0));
        }   
    }

    // Move actionbar
    if (Position.z == 2200 || Position.z == 2200.03) {
        gl_Position = ProjMat * ModelViewMat * (vec4(Position, 1.0) + vec4(0,10,0,0));
    }
    
    // Move Chat .0 .01 .03 .04
    if (Position.z >= 2650 && Position.z <= 2650.04 ) {
        gl_Position = ProjMat * ModelViewMat * (vec4(Position, 1.0) - vec4(0,30,0,0));
    }

    //  XP level             Item count                                                                                Advancement text
    if (Position.z == 600 || Position.z == 300 || Position.z == 300.03 || Position.z == 432 || Position.z == 432.03 || (iColor == vec3(64,64,64) && Position.z == 0)) {
        vertexColor = vec4(0,0,0,0);
    }

    flash = 0;
    float opacity = smoothstep(0,1,min(Color.a*2,1));
    // Animate Title
    if ((Position.z == 2400 && iColor == vec3(254,254,254))) {
        float size = smoothstep(0,0.3,Color.a)*0.5;
        flash = max(1.75-2*Color.a,0);
        vertexColor = vec4(1,1,1,opacity);
        
        // Move to center, scale up and then go to position
        gl_Position.y += 62/ScreenSize.y*guiScale;
        gl_Position.xy *= vec2(size,size);
        gl_Position.y += 1.0 - 75/ScreenSize.y*guiScale;
    }
    else if (Position.z == 2400 && iColor == vec3(254,254,253)) {
        vertexColor = vec4(1,1,1,step(1,opacity));
        
        // Move to center, scale up and then go to position
        gl_Position.y += 40/ScreenSize.y*guiScale;
        gl_Position.xy *= vec2(0.63,0.63);
        gl_Position.y += 1.0 - 78/ScreenSize.y*guiScale;
        gl_Position.x += (20.0 / ScreenSize.x) * 2.0 * guiScale;
    }

    // Move blank advancement text
    else if ((iColor == vec3(85,85,255) && Position.z == 0.03) || (iColor == vec3(21,21,63) && Position.z == 0)) {
        gl_Position.y += 113/ScreenSize.y*guiScale;
        gl_Position.z -= 0.1;
        vertexColor = vec4(Color.r*3,Color.g*3,Color.b,1);
    }
    // Hide advancement root titles
    else if (iColor == vec3(254,254,253)) {
        if(gl_Position.y > 130/ScreenSize.y*guiScale) vertexColor = vec4(Color.a,Color.a,Color.a,1);
        else vertexColor = vec4(0,0,0,0);
    }
    // Hide Challenge text except for menu screen
    else if (iColor == vec3(170,0,170) && Position.z == 0){
        vertexColor = vec4(0,0,0,0);
    }
    else if ((iColor == vec3(170,0,170) && Position.z == 0.03) || (iColor == vec3(42,0,42) && Position.z == 0)){
        if (gl_Position.y < 1.0-130/ScreenSize.y*guiScale) {
            float value = Color.x/2*3;
            vertexColor = vec4(value,value,value,1);
        }
        else vertexColor = vec4(0,0,0,0);
    }


    // Move advancement title box
    else if (iColor == vec3(254,254,252)) {
        gl_Position.x -= (32.0 / ScreenSize.x) * 2.0 * guiScale;
        vertexColor = vec4(1,1,1,1);
    }
    // Move advancement title text
    else if (iColor == vec3(254,254,251)) {
        gl_Position.y += 10/ScreenSize.y*guiScale;
        vertexColor = vec4(Color.a,Color.a,Color.a,1);
    }
    // Move advancement description
    else if (iColor == vec3(254,254,250)) {
        gl_Position.y += 9/ScreenSize.y*guiScale;
        gl_Position.x += (2 / ScreenSize.x) * 2.0 * guiScale;
        vertexColor = vec4(Color.a,Color.a,Color.a,1);
    }

    coord_c = gl_Position.xy / vec2(guiScale,guiScale) * ScreenSize;
    coord = Position.xy * vec2(0.001,0.001);
}